'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.resolveGraphiQLString = resolveGraphiQLString;

var _renderGraphiQL = require('./renderGraphiQL');

function isOptionsFunction(arg) {
  return typeof arg === 'function';
}

function resolveGraphiQLOptions(options) {
  if (isOptionsFunction(options)) {
    for (var _len = arguments.length, args = Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
      args[_key - 1] = arguments[_key];
    }

    return options.apply(undefined, args).catch(function (e) {
      throw new Error('Invalid options provided for GraphiQL: ' + e.message);
    });
  }

  return Promise.resolve(options);
}

function createGraphiQLParams(query) {
  var queryObject = query || {};
  return {
    query: queryObject.query || '',
    variables: queryObject.variables,
    operationName: queryObject.operationName || ''
  };
}

function createGraphiQLData(params, options) {
  return {
    endpointURL: options.endpointURL,
    subscriptionsEndpoint: options.subscriptionsEndpoint,
    query: params.query || options.query,
    variables: params.variables && JSON.parse(params.variables) || options.variables,
    operationName: params.operationName || options.operationName,
    passHeader: options.passHeader,
    editorTheme: options.editorTheme
  };
}

function resolveGraphiQLString(query, options) {
  var graphiqlParams = createGraphiQLParams(query);

  for (var _len2 = arguments.length, args = Array(_len2 > 2 ? _len2 - 2 : 0), _key2 = 2; _key2 < _len2; _key2++) {
    args[_key2 - 2] = arguments[_key2];
  }

  return resolveGraphiQLOptions.apply(undefined, [options].concat(args)).then(function (graphiqlOptions) {
    var graphiqlData = createGraphiQLData(graphiqlParams, graphiqlOptions);
    return (0, _renderGraphiQL.renderGraphiQL)(graphiqlData);
  });
}